# /etc/profile.d/lang.csh - set i18n stuff

set sourced=0
# Source only .i18n file if it exists
if ( -f "$HOME/.i18n" ) then
    eval `sed -ne 's|^[[:blank:]]*\([^#=]\{1,\}\)=\([^=]*\)|setenv \1 \2;|p' "$HOME/.i18n"`
    set sourced=1
else
# Read system enviroment variables if no locale variables are set
    if ( ! `locale | grep -q -v '=\"POSIX\"$\|^LANG=$\|^LC_ALL=$'` ) then
        if ( -e "`which gdbus`" ) then
            foreach l (`(gdbus call --system --dest org.freedesktop.systemd1 --object-path /org/freedesktop/systemd1 -m org.freedesktop.DBus.Properties.Get org.freedesktop.systemd1.Manager Environment | grep -oP "(?<=')(LANG|LANGUAGE|LC_\w+)=[^']*")`)
                # We get locale variables from system environment in form LANG=en_US.UTF-8
                eval `echo $l | sed -ne 's|^[[:blank:]]*\([^#=]\{1,\}\)=\([^=]*\)|setenv \1 \2;|p'`
                set sourced=1
            end
       endif
   endif
endif

if ($sourced == 1) then
    if ($?LC_ALL && $?LANG) then
        if ($LC_ALL == $LANG) then
            unsetenv LC_ALL
        endif
    endif
    
    set consoletype=`/sbin/consoletype stdout`

    if ($?LANG) then
        switch ($LANG)
	    case *.utf8*:
	    case *.UTF-8*:
		if ( $?TERM ) then
		    if ( "$TERM" == "linux" ) then
			if ( "$consoletype" == "vt" ) then
			    switch ($LANG)
			    	case en_IN*:
			    		breaksw
			    	case ja*:
			    	case ko*:
			    	case si*:
			    	case zh*:
			    	case ar*:
			    	case fa*:
			    	case he*:
			    	case *_IN*:
			    		setenv LANG en_US.UTF-8
			    		breaksw
			    endsw
			endif
		    endif
		endif
		breaksw
	    case *:
		if ( $?TERM ) then
		    if ( "$TERM" == "linux" ) then
			if ( "$consoletype" == "vt" ) then
			    switch ($LANG)
			    	case en_IN*:
			    		breaksw
			    	case ja*:
			    	case ko*:
			    	case si*:
			    	case zh*:
			    	case ar*:
			    	case fa*:
			    	case he*:
			    	case *_IN*:
			    		setenv LANG en_US
			    		breaksw
			    endsw
			endif
		    endif
		endif
		breaksw
	endsw
    endif    
    unsetenv SYSFONTACM
    unsetenv SYSFONT
    unsetenv consoletype
endif
unsetenv sourced
